@@ -7,7 +7,7 @@ import os
 import random
 import time
 import sqlite3
-from typing import Tuple
+from typing import Set, Tuple
 from arcnagios import arcutils, arcclients
 from arcnagios.ce.jobutils import JobNagiosPlugin
 from arcnagios.nagutils import OK, WARNING, CRITICAL, ServiceReport, ServiceOk
@@ -75,7 +75,12 @@ class Check_arcce_clean(JobNagiosPlugin):
     def time_left(self) -> float:
         return self.opts.timeout - time.time() + self._t_start
 
-    async def _prune_job(self, active_jobids, jobid, jobstat) -> PruneResult:
+    async def _prune_job(
+            self,
+            active_jobids: Set[str],
+            jobid: str,
+            jobstat: arcutils.Arcstat
+        ) -> PruneResult:
         if jobstat.submitted:
             tm_sub = time.strptime(jobstat.submitted, '%Y-%m-%d %H:%M:%S')
             t_sub = time.mktime(tm_sub)
