@@ -196,7 +196,7 @@ class Check_arcce_monitor(JobNagiosPlugin):
                 if arcget_result.get_error().output:
                     details = 'Output from arcget:\n%s' \
                             % arcget_result.get_error().output
-                    if self.opts.show_argget_output_here:
+                    if self.opts.show_arcget_output_here:
                         self.log.error(details)
                     termination_report.log.error(details)
                 termination_report.log.error('JID: %s', jobinfo.job_id)
