@@ -2,8 +2,9 @@
 
 import os
 import re
-from arcnagios.ce.jobplugin import JobPlugin
-from arcnagios.nagutils import OK, CRITICAL, UNKNOWN
+from typing import List, TextIO
+from arcnagios.ce.jobplugin import JobPlugin, StagingSpec
+from arcnagios.nagutils import OK, CRITICAL, UNKNOWN, NagiosReport
 
 _PRESENCE_SCRIPT = """\
 missing=
@@ -30,31 +31,35 @@ class ScriptedJobPlugin(JobPlugin):
     _status_re = re.compile(r'__status\s+(\d+)\s+(.*)')
     _log_re = re.compile(r'__log\s+(\d+)\s+(.*)')
 
-    def write_script(self, fh):
-        script_line = self.getconf('script_line')
+    def write_script(self, fh: TextIO, workdir: str) -> None:
+        script_line = self.getconf_str('script_line')
         fh.write('# Scripted test %s\n'%self.service_description)
-        output_file = self.getconf('output_file')
+        output_file = self.getconf_str('output_file')
         env = {
             'script_line': script_line,
             'output_file': output_file
         }
         if self.hasconf('required_programs'):
-            env['required_programs'] = self.getconf('required_programs')
+            env['required_programs'] = self.getconf_str('required_programs')
             fh.write(_PRESENCE_SCRIPT % env)
         else:
             fh.write(_PLAIN_SCRIPT % env)
         fh.write('\n')
 
-    def staged_inputs(self):
-        return self.getconf_strlist('staged_inputs', default = [])
+    def staged_inputs(self, workdir: str) -> List[StagingSpec]:
+        specs = self.getconf_strlist('staged_inputs', default = [])
+        return [StagingSpec.parse(spec, workdir) for spec in specs]
 
-    def staged_outputs(self):
-        return [(self.getconf('output_file'), None, [])]
+    def staged_outputs(self, workdir: str) -> List[StagingSpec]:
+        spec = self.getconf_str('output_file')
+        return [StagingSpec(spec, None, [])]
 
-    def check(self, report, jobdir, stored_urls):
-        output_file = os.path.join(jobdir, self.getconf('output_file'))
+    def check(
+            self, report: NagiosReport, jobdir: str, stored_urls: List[str]
+        ) -> None:
+        output_file = os.path.join(jobdir, self.getconf_str('output_file'))
         if self.hasconf('output_pattern'):
-            pattern_re = re.compile(self.getconf('output_pattern'))
+            pattern_re = re.compile(self.getconf_str('output_pattern'))
         else:
             pattern_re = None
         try:
@@ -63,7 +68,8 @@ class ScriptedJobPlugin(JobPlugin):
                     if pattern_re:
                         mo = re.match(pattern_re, line)
                         if mo:
-                            msg = self.getconf('status_ok', vars=mo.groupdict())
+                            msg = self.getconf_str('status_ok',
+                                                   subst=mo.groupdict())
                             report.update_status(OK, msg)
                             fh.close()
                             return
@@ -93,4 +99,5 @@ class ScriptedJobPlugin(JobPlugin):
             return
         if pattern_re:
             report.update_status(CRITICAL,
-                self.getconf('status_critical', default = 'Pattern not found.'))
+                self.getconf_str('status_critical',
+                                 default='Pattern not found.'))
