@@ -7,7 +7,7 @@ import os
 import shutil
 import time
 from typing import Dict, List, Optional, Set, Tuple
-import jinja2
+import jinja2 # type: ignore
 from arcnagios import arcclients, nagutils, persistence, vomsutils
 from arcnagios.arcutils import jobstate_of_str, ArcClient, JobState, ParseError
 from arcnagios.nagutils import NagiosPerflogTimer
@@ -15,18 +15,28 @@ from arcnagios.persistence import ObsoletePersistentObject
 from arcnagios.reputation import ReputationTracker
 from arcnagios.rescheduler import Rescheduler
 from arcnagios.utils import host_of_uri
-from arcnagios.ce.jobplugin import JobPlugin
+from arcnagios.ce.jobplugin import JobPlugin, StagingSpec
 from arcnagios.ce.jobplugins import load_jobplugin
 
 class JobDescription:
     _required_attributes = ["job_name", "application_name", "script_path"]
-    def __init__(self, job_name = None, application_name = None, logdir = None,
-                 script_path = None, script_args = None,
-                 output = 'stdout.txt', error = 'stderr.txt',
-                 wall_time_limit = None, memory_limit = None,
-                 staged_inputs = None, staged_outputs = None,
-                 runtime_environments = None,
-                 queue_name = None, template = 'default.xrsl.j2'):
+    def __init__(
+            self,
+            *,
+            job_name: str,
+            application_name: str,
+            logdir: Optional[str] = None,
+            script_path: str,
+            script_args: Optional[List[str]] = None,
+            output: str = 'stdout.txt',
+            error: str = 'stderr.txt',
+            wall_time_limit: Optional[int] = None,
+            memory_limit: Optional[int] = None,
+            staged_inputs: Optional[List[StagingSpec]] = None,
+            staged_outputs: Optional[List[StagingSpec]] = None,
+            runtime_environments: Optional[List[str]] = None,
+            queue_name: Optional[str] = None,
+            template: str = 'default.xrsl.j2'):
         self.template = template
         self.job_name = job_name or 'ARC Probe'
         self.application_name = application_name
@@ -137,15 +147,21 @@ class JobNagiosPlugin(nagutils.NagiosPlugin, vomsutils.NagiosPluginVomsMixin):
     cleaner_arcclean_timeout = 5
     cleaner_arckill_timeout = 5
 
+    arcclient: ArcClient
+    _reputation_tracker: ReputationTracker
+
     def _disconnect_reputation_tracker(self):
         if self._reputation_tracker is not None:
             self._reputation_tracker.disconnect()
 
-    def __init__(self, **kwargs):
+    def __init__(
+            self, use_host: bool = False, use_port: bool = False,
+            default_port: Optional[int] = None):
         default_template_dirs = glob(os.path.join(self.config_dir(),'*.d'))
         default_template_dirs.sort()
-        nagutils.NagiosPlugin.__init__(self, **kwargs)
-        self.arcclient = None
+        nagutils.NagiosPlugin.__init__(
+                self, use_host=use_host, use_port=use_port,
+                default_port=default_port)
 
         argp = self.argparser
         argp.add_argument('--fqan', dest = 'fqan')
@@ -165,7 +181,6 @@ class JobNagiosPlugin(nagutils.NagiosPlugin, vomsutils.NagiosPluginVomsMixin):
         argp.add_argument('--concurrency', type = int, default = 20,
                 help = 'The maximum number of ARC client processes to run '
                         'concurrently.')
-        self._reputation_tracker = None
         self.at_exit(self._disconnect_reputation_tracker)
 
     def parse_args(self, args: List[str]) -> None:
