@@ -108,18 +108,30 @@ class NagiosPerflog:
         self._granular = granular
         self._perfdatas: Dict[str, NagiosPerfdata] = {}
 
-    def add(self, label: str, value: float, **kwargs) -> None:
-        perfdata = NagiosPerfdata(label, value, **kwargs)
+    def add(self, label: str, value: float, uom: Optional[str] = None,
+            limit_warn: Optional[float] = None,
+            limit_crit: Optional[float] = None,
+            limit_min: Optional[float] = None,
+            limit_max: Optional[float] = None) -> None:
+        perfdata = NagiosPerfdata(
+                label, value, uom=uom,
+                limit_warn=limit_warn, limit_crit=limit_crit,
+                limit_min=limit_min, limit_max=limit_max)
         if label in self._perfdatas:
             perfdata += self._perfdatas[label]
         self._perfdatas[label] = perfdata
 
-    def addi(self, label: str, index: Optional[str], value: float, **kwargs) \
-            -> None:
+    def addi(self, label: str, index: Optional[str],
+             value: float, uom: Optional[str] = None,
+             limit_warn: Optional[float] = None,
+             limit_crit: Optional[float] = None,
+             limit_min: Optional[float] = None,
+             limit_max: Optional[float] = None) -> None:
         if self._granular and not index is None:
-            self.add(label + '[' + index + ']', value, **kwargs)
-        else:
-            self.add(label, value, **kwargs)
+            label += '[' + index + ']'
+        self.add(label, value, uom=uom,
+                 limit_warn=limit_warn, limit_crit=limit_crit,
+                 limit_min=limit_min, limit_max=limit_max)
 
     def is_empty(self) -> bool:
         return self._perfdatas == {}
@@ -394,7 +406,7 @@ class NagiosPlugin:
                 raise ServiceUnknown('Error importing %s: %s'
                                      % (module_name, exn)) from exn
 
-    def check(self) -> ServiceReport:
+    def check(self) -> Optional[ServiceReport]:
         """Override this method in your plugin to implement the test.  You
         should not call this directly, but use `nagios_run`, which will handle
         argument parsing and report results to Nagios."""
@@ -451,8 +463,19 @@ class NagiosPlugin:
             self.nagios_exit(UNKNOWN, msg)
         self.nagios_exit(service_report.status, service_report.message)
 
-    def add_perfdata(self, label: str, value: float, **kwargs):
-        self.perflog.add(label, value, **kwargs)
+    def add_perfdata(
+            self, label: str, value: float, uom: Optional[str] = None,
+            limit_warn: Optional[float] = None,
+            limit_crit: Optional[float] = None,
+            limit_min: Optional[float] = None,
+            limit_max: Optional[float] = None
+        ) -> None:
+        self.perflog.add(
+                label, value, uom=uom,
+                limit_warn=limit_warn,
+                limit_crit=limit_crit,
+                limit_min=limit_min,
+                limit_max=limit_max)
 
     def nagios_report_for(
             self, host_name: str, service_description: str, create = True):
