@@ -88,10 +88,13 @@ class Rescheduler:
         self._task_types[task_type_name] \
             = TaskType(h, min_delay, max_attempts, delay_dev)
 
-    def schedule(self, task_type_name: str, arg: str, n_attempts: int = 0) \
-            -> None:
+    def schedule(
+            self, task_type_name: str, arg: str,
+            n_attempts: int = 0, t_sched: Optional[float] = None
+        ) -> None:
         handler = self._task_types[task_type_name]
-        t_sched = time.time() + handler.next_delay(n_attempts)
+        if t_sched is None:
+            t_sched = time.time() + handler.next_delay(n_attempts)
         self._update('INSERT INTO %s (n_attempts, t_sched, task_type, arg) '
                      'VALUES (?, ?, ?, ?)' % self._table,
                      n_attempts, t_sched, task_type_name, arg)
@@ -125,7 +128,9 @@ class Rescheduler:
         resched_count = 0
         postponed_count = 0
 
-        async def process(rowid, n_attempts, t_sched, task_type_name, arg):
+        async def process(
+                rowid: int, n_attempts: int, t_sched: float,
+                task_type_name: str, arg: str):
             nonlocal success_count, failed_count, resched_count, postponed_count
 
             if not task_type_name in self._task_types:
