@@ -16,7 +16,7 @@ from arcnagios.nagutils import UNKNOWN
 log = logging.getLogger(__name__)
 
 class ProxyInitError(EnvironmentError):
-    def __init__(self, msg, details = None):
+    def __init__(self, msg: str, details: Optional[str] = None):
         EnvironmentError.__init__(self, msg)
         self.details = details
 
